@@ -119,6 +119,7 @@ d_drand48_r='undef'
 d_drand48proto='undef'
 d_dup2='undef'
 d_dup3='undef'
+d_duplocale='undef'
 d_eaccess='undef'
 d_endgrent='undef'
 d_endgrent_r='undef'
@@ -500,7 +501,6 @@ d_stdio_ptr_lval_sets_cnt='undef'
 d_stdio_stream_array='undef'
 d_stdiobase='undef'
 d_stdstdio='undef'
-d_strchr='undef'
 d_strcoll='undef'
 d_strerror_l='undef'
 d_strerror_r='undef'
@@ -509,6 +509,7 @@ d_strlcat='undef'
 d_strlcpy='undef'
 d_strnlen='undef'
 d_strtod='undef'
+d_strtod_l='undef'
 d_strtol='define'
 d_strtold='undef'
 d_strtold_l='undef'
